@@ -215,7 +215,6 @@ class BaseModel(ModelMixin, metaclass=ModelMeta):
                 ) from ex
         elif _type.__module__ == 'typing':
             new_val = parse_type(_type, value, _encoder)
-            print('AQUI >> ', name, new_val, type(new_val))
             return self._validation_(name, new_val, f, _type)
         elif isinstance(value, list) and hasattr(_type, '__args__'):
             new_val = self._handle_list_of_dataclasses(value, _type)
@@ -256,7 +255,7 @@ class BaseModel(ModelMixin, metaclass=ModelMeta):
                     f"::{self.modelName}:: Missing Required Field *{name}*"
                 )
         except KeyError:
-            pass
+            return
         # Nullable:
         try:
             if f.metadata["nullable"] is False and self.Meta.strict is True:
@@ -264,7 +263,8 @@ class BaseModel(ModelMixin, metaclass=ModelMeta):
                     f"::{self.modelName}:: *{name}* Cannot be null."
                 )
         except KeyError:
-            pass
+            return
+        return
 
     def _validation_(
         self,
@@ -283,7 +283,7 @@ class BaseModel(ModelMixin, metaclass=ModelMeta):
         if val_type == type or value == _type or is_empty(value):
             try:
                 self._field_checks_(f, name, value)
-                return True
+                return None
             except (ValueError, TypeError):
                 raise
         else:
